==> colorflood_0.3-3.tar.gz: colorflood-0.3/src/resources/tr/ru_RU.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru">
<context>
    <name>Board</name>
    <message>
        <location filename="../../board.cpp" line="280"/>
        <source>You won!
You used %1 turns out of %2.</source>
        <extracomment>win message</extracomment>
        <translation type="unfinished">Вы победили!
Вы использовали %1 из %2 ходов.</translation>
    </message>
    <message>
        <location filename="../../board.cpp" line="288"/>
        <source>You lost!</source>
        <extracomment>fail message</extracomment>
        <translation type="unfinished">Вы проиграли!</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../scheme.cpp" line="37"/>
        <source>Default scheme</source>
        <oldsource>Default</oldsource>
        <extracomment>default scheme name</extracomment>
        <translation type="unfinished">Стандартная схема</translation>
    </message>
    <message>
        <location filename="../../scheme.cpp" line="47"/>
        <source>Black-and-white scheme</source>
        <oldsource>Black-and-white</oldsource>
        <extracomment>black-and-white scheme name</extracomment>
        <translation type="unfinished">Чёрно-белая схема</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <location filename="../../window.cpp" line="64"/>
        <source>New game</source>
        <translation type="unfinished">Новая игра</translation>
    </message>
    <message>
        <location filename="../../window.cpp" line="96"/>
        <source>Help</source>
        <translation type="unfinished">Помощь</translation>
    </message>
    <message>
        <location filename="../../window.cpp" line="107"/>
        <source>Less cells</source>
        <translation type="unfinished">Меньше клеток</translation>
    </message>
    <message>
        <location filename="../../window.cpp" line="114"/>
        <source>More cells</source>
        <translation type="unfinished">Больше клеток</translation>
    </message>
    <message>
        <location filename="../../window.cpp" line="133"/>
        <source>Turns: %1/%2</source>
        <extracomment>number of turns</extracomment>
        <translation type="unfinished">Ходов: %1/%2</translation>
    </message>
    <message>
        <location filename="../../window.cpp" line="181"/>
        <source>The object of the game is to turn a board into one single color. Number of moves is limited. You start from top-left corner with one cell already flooded.
Good luck!</source>
        <translation type="unfinished">Цель игры - залить поле одним цветом. Количество ходов ограничено. Вы начинаете с верхнего левого угла с одной клеткой, которая уже залита.
Удачи!</translation>
    </message>
    <message>
        <location filename="../../window.cpp" line="211"/>
        <source>Best record: %1/%2</source>
        <extracomment>best number of turns</extracomment>
        <translation type="unfinished">Рекорд: %1/%2</translation>
    </message>
</context>
</TS>

==> colorflood_0.4-2.tar.gz: colorflood-0.4/src/resources/tr/ru_RU.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru">
<context>
    <name>Board</name>
    <message>
        <location filename="../../board.cpp" line="319"/>
        <source>You win!
You have used %1 turns out of %2.</source>
        <extracomment>win message</extracomment>
        <translation type="unfinished">Вы выиграли!
Вы использовали %1 из %2 ходов.</translation>
    </message>
    <message>
        <location filename="../../board.cpp" line="327"/>
        <source>You lose!</source>
        <extracomment>fail message</extracomment>
        <translation type="unfinished">Вы проиграли!</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../scheme.cpp" line="37"/>
        <source>Default scheme</source>
        <oldsource>Default</oldsource>
        <extracomment>default scheme name</extracomment>
        <translation type="unfinished">Стандартная схема</translation>
    </message>
    <message>
        <location filename="../../scheme.cpp" line="47"/>
        <source>Black-and-white scheme</source>
        <oldsource>Black-and-white</oldsource>
        <extracomment>black-and-white scheme name</extracomment>
        <translation type="unfinished">Чёрно-белая схема</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <location filename="../../window.cpp" line="68"/>
        <source>New game</source>
        <translation type="unfinished">Новая игра</translation>
    </message>
    <message>
        <location filename="../../window.cpp" line="103"/>
        <source>Help</source>
        <translation type="unfinished">Помощь</translation>
    </message>
    <message>
        <location filename="../../window.cpp" line="121"/>
        <source>Less cells</source>
        <translation type="unfinished">Меньше клеток</translation>
    </message>
    <message>
        <location filename="../../window.cpp" line="128"/>
        <source>More cells</source>
        <translation type="unfinished">Больше клеток</translation>
    </message>
    <message>
        <location filename="../../window.cpp" line="147"/>
        <source>Turns: %1/%2</source>
        <extracomment>number of turns</extracomment>
        <translation type="unfinished">Ходов: %1/%2</translation>
    </message>
    <message>
        <location filename="../../window.cpp" line="198"/>
        <source>The object of the game is to turn a board into one single color. Number of moves is limited. You start from top-left corner with one cell already flooded.
Good luck!</source>
        <translation type="unfinished">Цель игры - залить поле одним цветом. Количество ходов ограничено. Вы начинаете с верхнего левого угла с одной клеткой, которая уже залита.
Удачи!</translation>
    </message>
    <message>
        <location filename="../../window.cpp" line="264"/>
        <source>Best record: %1/%2</source>
        <extracomment>best number of turns</extracomment>
        <translation type="unfinished">Рекорд: %1/%2</translation>
    </message>
    <message>
        <location filename="../../window.cpp" line="293"/>
        <source>Games won: %1/%2</source>
        <extracomment>games won/played</extracomment>
        <translation type="unfinished">Выигранных игр: %1/%2</translation>
    </message>
    <message>
        <location filename="../../window.hpp" line="62"/>
        <source>Left-handed mode</source>
        <translation type="unfinished">Режим для левшей</translation>
    </message>
    <message>
        <location filename="../../window.hpp" line="63"/>
        <source>Right-handed mode</source>
        <translation type="unfinished">Режим для правшей</translation>
    </message>
</context>
</TS>
